/*******************************************************************************

  Copyright(c) 1999 - 2015 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  e1000 mailing list <e1000-devel@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#include <stdio.h>
#include "ethregs.h"

#define REGVAL(base, offset) *((uint32_t *) (base + offset))
#define printval32(i, name, val) \
    printf("\t(0x%05x) %-22s%08x\n", i, name, val)
extern int clr;
extern int offset;

static void printit32_array (int, char *, volatile void *, int);
static void printit32_array (int i, char *name, volatile void *mem, int array_len)
{
	int j,n=0, alreadyzero=0;
	char regname[16];

	printf ("name: %s  len: %d\n", name, array_len);

	for (j=i, n=0; n < array_len; n++, j += sizeof(u32)) {
		if (*(u32 *)(mem + j) == 0) {
			switch (alreadyzero) {
			case 0:
				alreadyzero = 1;
				break;
			case 1:
				printf("\t...\n");
				alreadyzero = 2;
				continue;
			case 2:
				continue;
			}
		} else
			alreadyzero = 0;
		sprintf(regname, "%s[%d]", name, n);
		printit32(j, regname, mem);
	}
}

void dump_I350_registers(volatile void *mem, u32 size)
{
	unsigned int i, j, n;
	uint32_t val;
	char name[16];

	for (i = 0; i < size; i += sizeof(u32)) {
		switch (i & 0xffffffff) {
		case E1000_CTRL:
			sprintf(name, "CTRL"); break;
		case E1000_STATUS:
			sprintf(name, "STATUS"); break;
		case E1000_EECD:
			sprintf(name, "EEC"); break;
		case E1000_EERD:
			sprintf(name, "EERD"); break;
		case E1000_CTRL_EXT:
			sprintf(name, "CTRL_EXT"); break;
		case E1000_FLA:
			sprintf(name, "FLA"); break;
		case E1000_MDIC:
			sprintf(name, "MDIC"); break;
		case E1000_SCTL:
			sprintf(name, "SERDESCTL"); break;
		case E1000_FCAL:
			sprintf(name, "FCAL"); break;
		case E1000_FCAH:
			sprintf(name, "FCAH"); break;
		case E1000_FCT:
			sprintf(name, "FCT"); break;
		case E1000_CONNSW:
			sprintf(name, "CONNSW"); break;
		case E1000_VET:
			sprintf(name, "VET"); break;
		case E1000_RCTL:
			sprintf(name, "RCTL"); break;
		case E1000_FCTTV:
			sprintf(name, "FCTTV"); break;
		case E1000_TXCW:
			sprintf(name, "TXCW"); break;
		case E1000_RXCW:
			sprintf(name, "RXCW"); break;
		case E1000_TCTL:
			sprintf(name, "TCTL"); break;
		case E1000_TCTL_EXT:
			sprintf(name, "TCTL_EXT"); break;
		case E1000_TIPG:
			sprintf(name, "TIPG"); break;
		case E1000_LEDCTL:
			sprintf(name, "LEDCTL"); break;
		case E1000_EEMNGCTL:
			sprintf(name, "EEMNGCTL"); break;
		case E1000_EEARBC:
			sprintf(name, "EEARBC"); break;
		case E1000_VPDDIAG:
			sprintf(name, "VPDDIAG"); break;
		case E1000_I2CCMD:
			sprintf(name, "I2CCMD"); break;
		case E1000_I2CPARAMS:
			sprintf(name, "I2CPARAMS"); break;
		case E1000_FLOP:
			sprintf(name, "FLOP"); break;
		case E1000_WDSTP:
			sprintf(name, "WDSTP"); break;
		case E1000_SWDSTS:
			sprintf(name, "WDSWSTS"); break;
		case E1000_FRTIMER:
			sprintf(name, "FRTIMER"); break;
		case E1000_TCPTIMER:
			sprintf(name, "TCPTIMER"); break;
		case E1000_ICR:
			if (!clr) continue;
			sprintf(name, "ICR"); break;
		case E1000_ICS:
			sprintf(name, "ICS"); break;
		case E1000_IMS:
			sprintf(name, "IMS"); break;
		case E1000_IMC:
			sprintf(name, "IMC"); break;
		case E1000_IAM:
			sprintf(name, "IAM"); break;
		case E1000_GPIE:
			sprintf(name, "GPIE"); break;
		case E1000_EICR:
			if (!clr) continue;
			sprintf(name, "EICR"); break;
		case E1000_EICS:
			sprintf(name, "EICS"); break;
		case E1000_EIMS:
			sprintf(name, "EIMS"); break;
		case E1000_EIMC:
			sprintf(name, "EIMC"); break;
		case E1000_EIAC:
			sprintf(name, "EIAC"); break;
		case E1000_EIAM:
			sprintf(name, "EIAM"); break;
		case E1000_IVAR0:
			sprintf(name, "IVAR");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_IVAR_MISC:
			sprintf(name, "IVAR_MISC"); break;
		case E1000_PBACL:
			sprintf(name, "PBACL"); break;

		case E1000_EITR(0):
			sprintf(name, "EITR");
			printit32_array(i, name, mem, 25);
			continue;
		case E1000_FCRTL:
			sprintf(name, "FCRTL0"); break;
		case E1000_FCRTH:
			sprintf(name, "FCRTH0"); break;
		case E1000_PBDIAG:
			sprintf(name, "PBDIAG"); break;
		case E1000_RXPBS:
			sprintf(name, "RXPBS"); break;
		case E1000_FCRTV:
			sprintf(name, "FCRTV"); break;
		case E1000_RDPUMB:
			sprintf(name, "RDPUMB"); break;
		case E1000_RDPUAD:
			sprintf(name, "RDPUAD"); break;
		case E1000_RDPUWD:
			sprintf(name, "RDPUWD"); break;
		case E1000_RDPURD:
			sprintf(name, "RDPURD"); break;
		case E1000_RDPUCTL:
			sprintf(name, "RDPUCTL"); break;
		case E1000_RDBAL(0):
			sprintf(name, "RDBAL[%d]", 0);
			printit32(E1000_RDBAL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_RDBAL(n), mem))) {
					sprintf(name, "RDBAL[%d]", n);
					printval32(E1000_RDBAL(n), name, val);
				}
			}
			continue;
		case E1000_RDBAH(0):
			sprintf(name, "RDBAH[%d]", 0);
			printit32(E1000_RDBAH(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_RDBAH(n), mem))) {
					sprintf(name, "RDBAH[%d]", n);
					printval32(E1000_RDBAH(n), name, val);
				}
			}
			continue;
		case E1000_RDLEN(0):
			sprintf(name, "RDLEN[%d]", 0);
			printit32(E1000_RDLEN(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_RDLEN(n), mem))) {
					sprintf(name, "RDLEN[%d]", n);
					printval32(E1000_RDLEN(n), name, val);
				}
			}
			continue;
		case E1000_RDH(0):
			sprintf(name, "RDH[%d]", 0);
			printit32(E1000_RDH(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_RDH(n), mem))) {
					sprintf(name, "RDH[%d]", n);
					printval32(E1000_RDH(n), name, val);
				}
			}
			continue;
		case E1000_RDT(0):
			sprintf(name, "RDT[%d]", 0);
			printit32(E1000_RDT(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_RDT(n), mem))) {
					sprintf(name, "RDT[%d]", n);
					printval32(E1000_RDT(n), name, val);
				}
			}
			continue;
		case E1000_SRRCTL(0):
			sprintf(name, "SRRCTL[%d]", 0);
			printit32(E1000_SRRCTL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_SRRCTL(n), mem))) {
					sprintf(name, "SRRCTL[%d]", n);
					printval32(E1000_SRRCTL(n), name, val);
				}
			}
			continue;
		case E1000_RXDCTL(0):
			sprintf(name, "RXDCTL[%d]", 0);
			printit32(E1000_RXDCTL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_RXDCTL(n), mem))) {
					sprintf(name, "RXDCTL[%d]", n);
					printval32(E1000_RXDCTL(n), name, val);
				}
			}
			continue;
		case E1000_DCA_RXCTRL(0):
			sprintf(name, "DCA_RXCTL[%d]", 0);
			printit32(E1000_DCA_RXCTRL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_DCA_RXCTRL(n), mem))) {
					sprintf(name, "DCA_RXCTL[%d]", n);
					printval32(E1000_DCA_RXCTRL(n), name, val);
				}
			}
			continue;
		case E1000_RQDPC(0):
			sprintf(name, "RQDPC[%d]", 0);
			printit32(E1000_RQDPC(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_RQDPC(n), mem))) {
					sprintf(name, "RQDPC[%d]", n);
					printval32(E1000_RQDPC(n), name, val);
				}
			}
			continue;
		case E1000_TXPBS:
			sprintf(name, "TXPBS"); break;
		case E1000_TDFH:
			sprintf(name, "TDFH"); break;
		case E1000_TDFT:
			sprintf(name, "TDFT"); break;
		case E1000_TDFHS:
			sprintf(name, "TDFHS"); break;
		case E1000_TDFPC:
			sprintf(name, "TDFPC"); break;
		case E1000_DTXCTL:
			sprintf(name, "DTXCTL"); break;
		case E1000_DTXTCPFLGL:
			sprintf(name, "DTXTCPFLGL"); break;
		case E1000_DTXTCPFLGH:
			sprintf(name, "DTXTCPFLGH"); break;
		case E1000_DTXMXSZRQ:
			sprintf(name, "DTXMXSZRQ"); break;
		case E1000_TDPUMB:
			sprintf(name, "TDPUMB"); break;
		case E1000_TDPUAD:
			sprintf(name, "TDPUAD"); break;
		case E1000_TDPUWD:
			sprintf(name, "TDPUWD"); break;
		case E1000_TDPURD:
			sprintf(name, "TDPURD"); break;
		case E1000_TDPUCTL:
			sprintf(name, "TDPUCTL"); break;
		case E1000_TDBAL(0):
			sprintf(name, "TDBAL[%d]", 0);
			printit32(E1000_TDBAL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TDBAL(n), mem))) {
					sprintf(name, "TDBAL[%d]", n);
					printval32(E1000_TDBAL(n), name, val);
				}
			}
			continue;
		case E1000_TDBAH(0):
			sprintf(name, "TDBAH[%d]", 0);
			printit32(E1000_TDBAH(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TDBAH(n), mem))) {
					sprintf(name, "TDBAH[%d]", n);
					printval32(E1000_TDBAH(n), name, val);
				}
			}
			continue;
		case E1000_TDLEN(0):
			sprintf(name, "TDLEN[%d]", 0);
			printit32(E1000_TDLEN(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TDLEN(n), mem))) {
					sprintf(name, "TDLEN[%d]", n);
					printval32(E1000_TDLEN(n), name, val);
				}
			}
			continue;
		case E1000_TDH(0):
			sprintf(name, "TDH[%d]", 0);
			printit32(E1000_TDH(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TDH(n), mem))) {
					sprintf(name, "TDH[%d]", n);
					printval32(E1000_TDH(n), name, val);
				}
			}
			continue;
		case E1000_DCA_TXCTRL(0):
			sprintf(name, "DCA_TXCTRL[%d]", 0);
			printit32(E1000_DCA_TXCTRL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_DCA_TXCTRL(n), mem))) {
					sprintf(name, "DCA_TXCTRL[%d]", n);
					printval32(E1000_DCA_TXCTRL(n), name, val);
				}
			}
			continue;
		case E1000_TDT(0):
			sprintf(name, "TDT[%d]", 0);
			printit32(E1000_TDT(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TDT(n), mem))) {
					sprintf(name, "TDT[%d]", n);
					printval32(E1000_TDT(n), name, val);
				}
			}
			continue;
		case E1000_TXDCTL(0):
			sprintf(name, "TXDCTL[%d]", 0);
			printit32(E1000_TXDCTL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TXDCTL(n), mem))) {
					sprintf(name, "TXDCTL[%d]", n);
					printval32(E1000_TXDCTL(n), name, val);
				}
			}
			continue;
		case E1000_TDWBAL(0):
			sprintf(name, "TDWBAL[%d]", 0);
			printit32(E1000_TDWBAL(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TDWBAL(n), mem))) {
					sprintf(name, "TDWBAL[%d]", n);
					printval32(E1000_TDWBAL(n), name, val);
				}
			}
			continue;
		case E1000_TDWBAH(0):
			sprintf(name, "TDWBAH[%d]", 0);
			printit32(E1000_TDWBAH(0), name, mem);
			for (n=1; n<16; n++) {
				if (0 != (val = REGVAL(E1000_TDWBAH(n), mem))) {
					sprintf(name, "TDWBAH[%d]", n);
					printval32(E1000_TDWBAH(n), name, val);
				}
			}
			continue;

		/* subset of virtualization registers: just the ones #defined
		 * in shared code */

		case E1000_SWPBS:
			sprintf(name, "SWPBS"); break;
		case E1000_V2PMAILBOX(0):
			sprintf(name, "V2PMAILBOX");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_P2VMAILBOX(0):
			sprintf(name, "P2VMAILBOX");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_MBVFICR:
			sprintf(name, "MBVFICR"); break;
		case E1000_MBVFIMR:
			sprintf(name, "MBVFIMR"); break;
		case E1000_VFLRE:
			sprintf(name, "VFLRE"); break;
		case E1000_VFRE:
			sprintf(name, "VFRE"); break;
		case E1000_VFTE:
			sprintf(name, "VFTE"); break;
		case E1000_QDE:
			sprintf(name, "QDE"); break;
		case E1000_DTXSWC:
			sprintf(name, "DTXSWC"); break;
		case E1000_VLVF(0):
			sprintf(name, "VLVF");
			printit32_array(i, name, mem, 32);
			continue;
		case E1000_VMOLR(0):
			sprintf(name, "VMOLR");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_VMVIR(0):
			sprintf(name, "VMVIR");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_RPLOLR:
			sprintf(name, "RPLOLR"); break;
		case E1000_UTA:
			sprintf(name, "UTA");
			printit32_array(i, name, mem, 128);
			continue;
		case E1000_VMRCTL:
			sprintf(name, "VMRCTL");
			printit32_array(i, name, mem, 4);
			continue;

		/* starting with a subset of eedc registers */

		case E1000_RTTDCS:
			sprintf(name, "RTTDCS"); break;
		case E1000_RTTPCS:
			sprintf(name, "RTTPCS"); break;
		case E1000_RTRPCS:
			sprintf(name, "RTRPCS"); break;
		case E1000_RTTBCNRC:
			sprintf(name, "RTTBCNRC"); break;
		case E1000_RTTBCNRS:
			sprintf(name, "RTTBCNRS"); break;
		case E1000_RTTBCNCR:
			sprintf(name, "RTTBCNCR"); break;

		/* statistics */

		case E1000_CRCERRS:
			if (!clr) continue;
			sprintf(name, "CRCERRS"); break;
		case E1000_ALGNERRC:
			if (!clr) continue;
			sprintf(name, "ALGNERRC"); break;
		case E1000_SYMERRS:
			if (!clr) continue;
			sprintf(name, "SYMERRS"); break;
		case E1000_RXERRC:
			if (!clr) continue;
			sprintf(name, "RXERRC"); break;
		case E1000_MPC:
			if (!clr) continue;
			sprintf(name, "MPC"); break;
		case E1000_SCC:
			if (!clr) continue;
			sprintf(name, "SCC"); break;
		case E1000_ECOL:
			if (!clr) continue;
			sprintf(name, "ECOL"); break;
		case E1000_MCC:
			if (!clr) continue;
			sprintf(name, "MCC"); break;
		case E1000_LATECOL:
			if (!clr) continue;
			sprintf(name, "LATECOL"); break;
		case E1000_COLC:
			if (!clr) continue;
			sprintf(name, "COLC"); break;
		case E1000_CBTMPC:
			if (!clr) continue;
			sprintf(name, "CBTMPC"); break;
		case E1000_DC:
			if (!clr) continue;
			sprintf(name, "DC"); break;
		case E1000_TNCRS:
			if (!clr) continue;
			sprintf(name, "TNCRS"); break;
		case E1000_SEC:
			if (!clr) continue;
			sprintf(name, "SEC"); break;
		case E1000_HTDPMC:
			if (!clr) continue;
			sprintf(name, "HTDPMC"); break;
		case E1000_RLEC:
			if (!clr) continue;
			sprintf(name, "RLEC"); break;
		case E1000_CBRDPC:
			if (!clr) continue;
			sprintf(name, "CBRDPC"); break;
		case E1000_XONRXC:
			if (!clr) continue;
			sprintf(name, "XONRXC"); break;
		case E1000_XONTXC:
			if (!clr) continue;
			sprintf(name, "XONTXC"); break;
		case E1000_XOFFRXC:
			if (!clr) continue;
			sprintf(name, "XOFFRXC"); break;
		case E1000_XOFFTXC:
			if (!clr) continue;
			sprintf(name, "XOFFTXC"); break;
		case E1000_FCRUC:
			if (!clr) continue;
			sprintf(name, "FCRUC"); break;
		case E1000_PRC64:
			if (!clr) continue;
			sprintf(name, "PRC64"); break;
		case E1000_PRC127:
			if (!clr) continue;
			sprintf(name, "PRC127"); break;
		case E1000_PRC255:
			if (!clr) continue;
			sprintf(name, "PRC255"); break;
		case E1000_PRC511:
			if (!clr) continue;
			sprintf(name, "PRC511"); break;
		case E1000_PRC1023:
			if (!clr) continue;
			sprintf(name, "PRC1023"); break;
		case E1000_PRC1522:
			if (!clr) continue;
			sprintf(name, "PRC1522"); break;
		case E1000_GPRC:
			if (!clr) continue;
			sprintf(name, "GPRC"); break;
		case E1000_BPRC:
			if (!clr) continue;
			sprintf(name, "BPRC"); break;
		case E1000_MPRC:
			if (!clr) continue;
			sprintf(name, "MPRC"); break;
		case E1000_GPTC:
			if (!clr) continue;
			sprintf(name, "GPTC"); break;
		case E1000_GORCL:
			if (!clr) continue;
			sprintf(name, "GORCL"); break;
		case E1000_GORCH:
			if (!clr) continue;
			sprintf(name, "GORCH"); break;
		case E1000_GOTCL:
			if (!clr) continue;
			sprintf(name, "GOTCL"); break;
		case E1000_GOTCH:
			if (!clr) continue;
			sprintf(name, "GOTCH"); break;
		case E1000_RNBC:
			if (!clr) continue;
			sprintf(name, "RNBC"); break;
		case E1000_RUC:
			if (!clr) continue;
			sprintf(name, "RUC"); break;
		case E1000_RFC:
			if (!clr) continue;
			sprintf(name, "RFC"); break;
		case E1000_ROC:
			if (!clr) continue;
			sprintf(name, "ROC"); break;
		case E1000_RJC:
			if (!clr) continue;
			sprintf(name, "RJC"); break;
		case E1000_MGTPRC:
			if (!clr) continue;
			sprintf(name, "MGTPRC"); break;
		case E1000_MGTPDC:
			if (!clr) continue;
			sprintf(name, "MGTPDC"); break;
		case E1000_MGTPTC:
			if (!clr) continue;
			sprintf(name, "MGTPTC"); break;
		case E1000_TORL:
			if (!clr) continue;
			sprintf(name, "TORL"); break;
		case E1000_TORH:
			if (!clr) continue;
			sprintf(name, "TORH"); break;
		case E1000_TOTL:
			if (!clr) continue;
			sprintf(name, "TOTL"); break;
		case E1000_TOTH:
			if (!clr) continue;
			sprintf(name, "TOTH"); break;
		case E1000_TPR:
			if (!clr) continue;
			sprintf(name, "TPR"); break;
		case E1000_TPT:
			if (!clr) continue;
			sprintf(name, "TPT"); break;
		case E1000_PTC64:
			if (!clr) continue;
			sprintf(name, "PTC64"); break;
		case E1000_PTC127:
			if (!clr) continue;
			sprintf(name, "PTC127"); break;
		case E1000_PTC255:
			if (!clr) continue;
			sprintf(name, "PTC255"); break;
		case E1000_PTC511:
			if (!clr) continue;
			sprintf(name, "PTC511"); break;
		case E1000_PTC1023:
			if (!clr) continue;
			sprintf(name, "PTC1023"); break;
		case E1000_PTC1522:
			if (!clr) continue;
			sprintf(name, "PTC1522"); break;
		case E1000_MPTC:
			if (!clr) continue;
			sprintf(name, "MPTC"); break;
		case E1000_BPTC:
			if (!clr) continue;
			sprintf(name, "BPTC"); break;
		case E1000_TSCTC:
			if (!clr) continue;
			sprintf(name, "TSCTC"); break;
		case E1000_CBRMPC:
			if (!clr) continue;
			sprintf(name, "CBRMPC"); break;
		case E1000_IAC:
			if (!clr) continue;
			sprintf(name, "IAC"); break;
		case E1000_RPTHC:
			if (!clr) continue;
			sprintf(name, "RPTHC"); break;
		case E1000_HGPTC:
			if (!clr) continue;
			sprintf(name, "HGPTC"); break;
		case E1000_ICRXDMTC:
			if (!clr) continue;
			sprintf(name, "ICRXDMTC"); break;
		case E1000_HTCBDPC:
			if (!clr) continue;
			sprintf(name, "HTCBDPC"); break;
		case E1000_HGORCL:
			if (!clr) continue;
			sprintf(name, "HGORCL"); break;
		case E1000_HGORCH:
			if (!clr) continue;
			sprintf(name, "HGORCH"); break;
		case E1000_HGOTCL:
			if (!clr) continue;
			sprintf(name, "HGOTCL"); break;
		case E1000_HGOTCH:
			if (!clr) continue;
			sprintf(name, "HGOTCH"); break;
		case E1000_LENERRS:
			if (!clr) continue;
			sprintf(name, "LENERRS"); break;
		case E1000_PCS_CFG0:
			if (!clr) continue;
			sprintf(name, "PCS_CFG0"); break;
		case E1000_PCS_LCTL:
			if (!clr) continue;
			sprintf(name, "PCS_LCTRL"); break;
		case E1000_PCS_LSTAT:
			if (!clr) continue;
			sprintf(name, "PCS_LSTAT"); break;
		case E1000_PCS_ANADV:
			if (!clr) continue;
			sprintf(name, "PCS_ANADV"); break;
		case E1000_PCS_LPAB:
			if (!clr) continue;
			sprintf(name, "PCS_LPAB"); break;
		case E1000_PCS_NPTX:
			if (!clr) continue;
			sprintf(name, "PCS_NPTX"); break;
		case E1000_PCS_LPABNP:
			if (!clr) continue;
			sprintf(name, "PCS_LPABNP"); break;
		case E1000_SCVPC:
			if (!clr) continue;
			sprintf(name, "SCVPC"); break;
		case E1000_RXCSUM:
			sprintf(name, "RXCSUM"); break;
		case E1000_RLPML:
			sprintf(name, "RLPML"); break;
		case E1000_RFCTL:
			sprintf(name, "RFCTL"); break;
		case E1000_MTA:
			sprintf(name, "MTA");
			printit32_array(i, name, mem, 128);
			continue;
		case E1000_RA:
			sprintf(name, "RAL[%d]", 0);
			printit32(E1000_RAL(0), name, mem);
			sprintf(name, "RAH[%d]", 0);
			printit32(E1000_RAH(0), name, mem);
			for (n=1; n<24; n++) {
				/* note only RAL(n) is checked to control
				 * print of both RAL(n) and RAH()n) */
				if (0 != (val = REGVAL(E1000_RAL(n), mem))) {
					sprintf(name, "RAL[%d]", n);
					printval32(E1000_RAL(n), name, val);
					sprintf(name, "RAH[%d]", n);
					printit32(E1000_RAH(n), name, mem);
				}
			}
			continue;
		case E1000_PSRTYPE(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PSRTYPE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_VFTA:
			sprintf(name, "VFTA");
			printit32_array(i, name, mem, 128);
			continue;

		/* wakeup */

		case E1000_WUC:
			sprintf(name, "WUC"); break;
		case E1000_WUFC:
			sprintf(name, "WUFC"); break;
		case E1000_WUS:
			sprintf(name, "WUS"); break;

		case E1000_MRQC:
			sprintf(name, "MRQC"); break;
		case E1000_VT_CTL:
			sprintf(name, "VT_CTL"); break;
		case E1000_MANC:
			sprintf(name, "MANC"); break;
		case E1000_IPAV:
			sprintf(name, "IPAV"); break;
		case E1000_MANC2H:
			sprintf(name, "MANC2H"); break;
		case E1000_WUPL:
			if (!clr) continue;
			sprintf(name, "WUPL"); break;
		case E1000_IMIR(0):
			sprintf(name, "IMIR");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_IMIREXT(0):
			sprintf(name, "IMIREX");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_IMIRVP:
			sprintf(name, "IMIRVP"); break;
		case E1000_GCR:
			sprintf(name, "GCR"); break;
		case E1000_GSCL_1:
			sprintf(name, "GSCL_1"); break;
		case E1000_GSCL_2:
			sprintf(name, "GSCL_2"); break;
		case E1000_GSCL_3:
			sprintf(name, "GSCL_3"); break;
		case E1000_GSCL_4:
			sprintf(name, "GSCL_4"); break;
		case E1000_FACTPS:
			sprintf(name, "FACTPS"); break;
		case E1000_FWSM:
			sprintf(name, "FWSM"); break;
		case E1000_SW_FW_SYNC:
			sprintf(name, "SW_FW_SYNC"); break;
		case E1000_DCA_ID:
			sprintf(name, "DCA_ID"); break;
		case E1000_DCA_CTRL:
			sprintf(name, "DCA_CTRL"); break;
		case E1000_RETA(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "RETA[%d]", n);
				printit8(j, name, mem);
				j += sizeof(u8);
			}
			continue;
		case E1000_RSSRK(0):
			for (j=i, n=0; n<40; n++) {
				sprintf(name, "RSSRK[%d]", n);
				printit8(j, name, mem);
				j += sizeof(u8);
			}
			continue;
		case E1000_SAQF(0):
			sprintf(name, "SAQF");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_DAQF(0):
			sprintf(name, "DAQF");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_SPQF(0):
			sprintf(name, "SPQF");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_FTQF(0):
			sprintf(name, "FTQF");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_SYNQF(0):
			sprintf(name, "SYNQF"); break;
			/* EEE REGISTER DUMP */
		case E1000_IPCNFG:
			sprintf(name, "IPCNFG"); break;
		case E1000_LTRC:
			sprintf(name, "LTRC"); break;
		case E1000_EEER:
			sprintf(name, "EEER"); break;
		case E1000_EEE_SU:
			sprintf(name, "EEE_SU"); break;
		case E1000_TLPIC:
			sprintf(name, "TLPIC"); break;
		case E1000_RLPIC:
			sprintf(name, "RLPIC"); break;
			/* DMAC Register */
		case E1000_DMCTXTH:
		/* EAS and SHARED CODE disagree on the name of this offset*/
			sprintf(name, "DMCTXTH"); break;
		case E1000_DMCTLX:
			sprintf(name, "DMCTLX"); break;
		case E1000_DMCRTRH:
			sprintf(name, "DMCRTRH"); break;
		case E1000_DMCCNT:
			sprintf(name, "DMCCNT"); break;
		case E1000_ETQF(0):
			sprintf(name, "ETQF");
			printit32_array(i, name, mem, 8);
			continue;
		case E1000_HICR:
			sprintf(name, "HICR"); break;
		/* Time Sync */
		case E1000_TSYNCRXCTL:
			sprintf(name, "TSYNCRXCTL"); break;
		case E1000_TSYNCTXCTL:
			sprintf(name, "TSYNCTXCTL"); break;
		case E1000_TSYNCRXCFG:
			sprintf(name, "TSYNCRXCFG"); break;
		case E1000_RXSTMPL:
			sprintf(name, "RXSTMPL"); break;
		case E1000_RXSTMPH:
			sprintf(name, "RXSTMPH"); break;
		case E1000_RXSATRL:
			sprintf(name, "RXSATRL"); break;
		case E1000_RXSATRH:
			sprintf(name, "RXSATRH"); break;
		case E1000_TXSTMPL:
			sprintf(name, "TXSTMPL"); break;
		case E1000_TXSTMPH:
			sprintf(name, "TXSTMPH"); break;
		case E1000_SYSTIML:
			sprintf(name, "SYSTIML"); break;
		case E1000_SYSTIMH:
			sprintf(name, "SYSTIMH"); break;
		case E1000_TIMINCA:
			sprintf(name, "TIMINCA"); break;
		default:
			continue;
		}
		printit32(i, name, mem);
	}
}

// vi:ts=4:sw=4:ht=4:
